summaryrefslogtreecommitdiff
path: root/src/gui/windows/updaterwindow.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/gui/windows/updaterwindow.cpp')
-rw-r--r--src/gui/windows/updaterwindow.cpp18
1 files changed, 9 insertions, 9 deletions
diff --git a/src/gui/windows/updaterwindow.cpp b/src/gui/windows/updaterwindow.cpp
index 90f552383..cec56bb9b 100644
--- a/src/gui/windows/updaterwindow.cpp
+++ b/src/gui/windows/updaterwindow.cpp
@@ -1,10 +1,10 @@
/*
* The ManaPlus Client
* Copyright (C) 2004-2009 The Mana World Development Team
* Copyright (C) 2009-2010 The Mana Developers
* Copyright (C) 2011-2019 The ManaPlus Developers
*
* This file is part of The ManaPlus Client.
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
@@ -460,7 +460,7 @@ void UpdaterWindow::loadPatch()
if (line != nullptr)
{
mBrowserBox->addRow(strprintf("##9 Latest client version: "
- "##6ManaPlus %s##0", line), true);
+ "##6ManaVerse %s##0", line), true);
}
}
if (version > CHECK_VERSION)
@@ -482,7 +482,7 @@ void UpdaterWindow::loadPatch()
branding.getStringValue(url)).append("|").append(
branding.getStringValue(text)).append("@@]"), true);
mBrowserBox->addRow("##1You can download it from", true);
- mBrowserBox->addRow("##1ManaPlus updated.", true);
+ mBrowserBox->addRow("##1ManaVerse updated.", true);
}
else
{
@@ -680,7 +680,7 @@ void UpdaterWindow::loadUpdates()
file.name,
Append_false);
}
- loadManaPlusUpdates(mUpdatesDir);
+ loadManaVerseUpdates(mUpdatesDir);
loadMods(mUpdatesDir, mUpdateFiles);
}
@@ -713,7 +713,7 @@ void UpdaterWindow::loadLocalUpdates(const std::string &dir)
file.name,
Append_false);
}
- loadManaPlusUpdates(dir);
+ loadManaVerseUpdates(dir);
loadMods(dir, updateFiles);
}
@@ -739,10 +739,10 @@ void UpdaterWindow::unloadUpdates(const std::string &dir)
fixPath,
updateFiles[updateIndex].name);
}
- unloadManaPlusUpdates(dir);
+ unloadManaVerseUpdates(dir);
}
-void UpdaterWindow::loadManaPlusUpdates(const std::string &dir)
+void UpdaterWindow::loadManaVerseUpdates(const std::string &dir)
{
std::string fixPath = dir + "/fix";
STD_VECTOR<UpdateFile> updateFiles = loadXMLFile(
@@ -772,7 +772,7 @@ void UpdaterWindow::loadManaPlusUpdates(const std::string &dir)
}
}
-void UpdaterWindow::unloadManaPlusUpdates(const std::string &dir)
+void UpdaterWindow::unloadManaVerseUpdates(const std::string &dir)
{
const std::string fixPath = dir + "/fix";
const STD_VECTOR<UpdateFile> updateFiles = loadXMLFile(
@@ -1,10 +1,10 @@
/*
- * The ManaPlus Client
+ * The ManaVerse Client
* Copyright (C) 2004-2009 The Mana World Development Team
* Copyright (C) 2009-2010 The Mana Developers
@@ -1,10 +1,10 @@
* Copyright (C) 2011-2019 The ManaPlus Developers
*
- * This file is part of The ManaPlus Client.
+ * This file is part of The ManaVerse Client.
*
* This program is free software; you can redistribute it and/or modify